@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ class CControllerMenuPopup extends CController {
 	private static function getMenuDataDashboard(array $data) {
 		$db_dashboards = API::Dashboard()->get([
 			'output' => [],
-			'dashboardids' => $data['dashboardid'],
+			'dashboardids' => $data['dashboardid']
 		]);
 
 		if ($db_dashboards) {
@@ -458,7 +458,7 @@ class CControllerMenuPopup extends CController {
 
 					case SYSMAP_ELEMENT_TYPE_IMAGE:
 						$menu_data = [
-							'type' => 'map_element_image',
+							'type' => 'map_element_image'
 						];
 						if ($selement['urls']) {
 							$menu_data['urls'] = $selement['urls'];
@@ -662,18 +662,26 @@ class CControllerMenuPopup extends CController {
 			$menu_data['params'] = $data['params'];
 		}
 
-		if ($data['widgetType'] == WIDGET_GRAPH && array_key_exists('graphid', $data) && $data['graphid']) {
-			$menu_data['download'] = (bool) API::Graph()->get([
-				'output' => ['graphid'],
-				'graphids' => $data['graphid']
-			]);
-		}
-		elseif ($data['widgetType'] == WIDGET_GRAPH && array_key_exists('itemid', $data) && $data['itemid']) {
-			$menu_data['download'] = (bool) API::Item()->get([
-				'output' => ['itemid'],
-				'itemids' => $data['itemid'],
-				'webitems' => true
-			]);
+		if ($data['widgetType'] == WIDGET_GRAPH) {
+			$options = [];
+
+			if (array_key_exists('dynamic_hostid', $data)) {
+				$options['hostids'] = $data['dynamic_hostid'];
+			}
+
+			if (array_key_exists('graphid', $data) && $data['graphid']) {
+				$menu_data['download'] = (bool) API::Graph()->get($options + [
+					'output' => ['graphid'],
+					'graphids' => $data['graphid']
+				]);
+			}
+			elseif (array_key_exists('itemid', $data) && $data['itemid']) {
+				$menu_data['download'] = (bool) API::Item()->get($options + [
+					'output' => ['itemid'],
+					'itemids' => $data['itemid'],
+					'webitems' => true
+				]);
+			}
 		}
 
 		return $menu_data;
