@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 if ($data['uncheck']) {
 	uncheckTableRows('script');
 }
@@ -31,7 +35,7 @@ $widget = (new CWidget())
 		))
 			->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem((new CFilter())
+	->addItem((new CFilter((new CUrl('zabbix.php'))->setArgument('action', 'script.list')))
 		->setProfile($data['profileIdx'])
 		->setActiveTab($data['active_tab'])
 		->addFilterTab(_('Filter'), [
@@ -48,15 +52,20 @@ $scriptsForm = (new CForm())
 	->setName('scriptsForm')
 	->setId('scripts');
 
+$url = (new CUrl('zabbix.php'))
+	->setArgument('action', 'script.list')
+	->getUrl();
+
 $scriptsTable = (new CTableInfo())
 	->setHeader([
 		(new CColHeader(
-			(new CCheckBox('all_scripts'))->onClick("checkAll('".$scriptsForm->getName()."', 'all_scripts', 'scriptids');")
+			(new CCheckBox('all_scripts'))
+				->onClick("checkAll('".$scriptsForm->getName()."', 'all_scripts', 'scriptids');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder'], $url),
 		_('Type'),
 		_('Execute on'),
-		make_sorting_header(_('Commands'), 'command', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Commands'), 'command', $data['sort'], $data['sortorder'], $url),
 		_('User group'),
 		_('Host group'),
 		_('Host access')
@@ -96,7 +105,9 @@ foreach ($data['scripts'] as $script) {
 		))->addClass(ZBX_STYLE_NOWRAP),
 		$scriptType,
 		$scriptExecuteOn,
-		zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8')),
+		(new CCol(
+			zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8'))
+		))->addClass(ZBX_STYLE_MONOSPACE_FONT),
 		($script['userGroupName'] === null) ? _('All') : $script['userGroupName'],
 		($script['hostGroupName'] === null) ? _('All') : $script['hostGroupName'],
 		($script['host_access'] == PERM_READ_WRITE) ? _('Write') : _('Read')
@@ -113,4 +124,6 @@ $scriptsForm->addItem([
 ]);
 
 // append form to widget
-$widget->addItem($scriptsForm)->show();
+$widget
+	->addItem($scriptsForm)
+	->show();
