@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $options = [
 	'resourcetype' => SCREEN_RESOURCE_PROBLEM,
 	'mode' => SCREEN_MODE_JS,
@@ -28,7 +32,6 @@ $options = [
 		'action' => $data['action'],
 		'sort' => $data['sort'],
 		'sortorder' => $data['sortorder'],
-		'page' => $data['page'],
 		'filter' => [
 			'show' => $data['filter']['show'],
 			'groupids' => $data['filter']['groupids'],
@@ -36,7 +39,7 @@ $options = [
 			'application' => $data['filter']['application'],
 			'triggerids' => $data['filter']['triggerids'],
 			'name' => $data['filter']['name'],
-			'severity' => $data['filter']['severity'],
+			'severities' => $data['filter']['severities'],
 			'inventory' => $data['filter']['inventory'],
 			'evaltype' => $data['filter']['evaltype'],
 			'tags' => $data['filter']['tags'],
@@ -48,7 +51,8 @@ $options = [
 			'compact_view' => $data['filter']['compact_view'],
 			'show_timeline' => $data['filter']['show_timeline'],
 			'details' => $data['filter']['details'],
-			'highlight_row' => $data['filter']['highlight_row']
+			'highlight_row' => $data['filter']['highlight_row'],
+			'show_opdata' => $data['filter']['show_opdata']
 		]
 	]
 ];
@@ -70,7 +74,7 @@ switch ($data['filter']['show']) {
 
 $screen = CScreenBuilder::getScreen($options);
 
-if ($data['action'] == 'problem.view') {
+if ($data['action'] === 'problem.view') {
 	if ($data['filter']['show'] == TRIGGERS_OPTION_ALL) {
 		$this->addJsFile('class.calendar.js');
 	}
@@ -78,7 +82,11 @@ if ($data['action'] == 'problem.view') {
 	$this->addJsFile('flickerfreescreen.js');
 	$this->addJsFile('multiselect.js');
 	$this->addJsFile('layout.mode.js');
-	require_once dirname(__FILE__).'/monitoring.problem.view.js.php';
+
+	$this->includeJsFile('monitoring.problem.view.js.php');
+
+	$this->enableLayoutModes();
+	$web_layout_mode = $this->getLayoutMode();
 
 	if ($data['uncheck']) {
 		uncheckTableRows('problem');
@@ -102,7 +110,9 @@ if ($data['action'] == 'problem.view') {
 						'srctbl' => 'host_groups',
 						'srcfld1' => 'groupid',
 						'dstfrm' => 'zbx_filter',
-						'dstfld1' => 'filter_groupids_'
+						'dstfld1' => 'filter_groupids_',
+						'real_hosts' => true,
+						'enrich_parent_groups' => true
 					]
 				]
 			]))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
@@ -113,6 +123,9 @@ if ($data['action'] == 'problem.view') {
 				'object_name' => 'hosts',
 				'data' => $data['filter']['hosts'],
 				'popup' => [
+					'filter_preselect_fields' => [
+						'hostgroups' => 'filter_groupids_'
+					],
 					'parameters' => [
 						'srctbl' => 'hosts',
 						'srcfld1' => 'hostid',
@@ -127,15 +140,15 @@ if ($data['action'] == 'problem.view') {
 				->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH),
 			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 			(new CButton('filter_application_select', _('Select')))
-				->onClick('return PopUp("popup.generic",'.
-					CJs::encodeJson([
+				->onClick('return PopUp("popup.generic", jQuery.extend('.
+					json_encode([
 						'srctbl' => 'applications',
 						'srcfld1' => 'name',
 						'dstfrm' => 'zbx_filter',
 						'dstfld1' => 'filter_application',
 						'with_applications' => '1',
 						'real_hosts' => '1'
-					]).', null, this);'
+					]).', getFirstMultiselectValue("filter_hostids_")), null, this);'
 				)
 				->addClass(ZBX_STYLE_BTN_GREY)
 		])
@@ -145,6 +158,9 @@ if ($data['action'] == 'problem.view') {
 				'object_name' => 'triggers',
 				'data' => $data['filter']['triggers'],
 				'popup' => [
+					'filter_preselect_fields' => [
+						'hosts' => 'filter_hostids_'
+					],
 					'parameters' => [
 						'srctbl' => 'triggers',
 						'srcfld1' => 'triggerid',
@@ -160,8 +176,8 @@ if ($data['action'] == 'problem.view') {
 		->addRow(_('Problem'),
 			(new CTextBox('filter_name', $data['filter']['name']))->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 		)
-		->addRow(_('Minimum severity'),
-			new CComboBox('filter_severity', $data['filter']['severity'], null, $data['filter']['severities'])
+		->addRow(_('Severity'),
+			(new CSeverityCheckBoxList('filter_severities'))->setChecked($data['filter']['severities'])
 		);
 
 	$filter_age = (new CNumericBox('filter_age', $data['filter']['age'], 3, false, false, false))
@@ -174,7 +190,7 @@ if ($data['action'] == 'problem.view') {
 		->addRow(_('Age less than'), [
 			(new CCheckBox('filter_age_state'))
 				->setChecked($data['filter']['age_state'] == 1)
-				->onClick('javascript: this.checked ? $("filter_age").enable() : $("filter_age").disable()'),
+				->onClick('javascript: jQuery("#filter_age").prop("disabled", !this.checked)'),
 			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 			$filter_age,
 			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
@@ -191,7 +207,9 @@ if ($data['action'] == 'problem.view') {
 	$i = 0;
 	foreach ($filter_inventory as $field) {
 		$filter_inventory_table->addRow([
-			new CComboBox('filter_inventory['.$i.'][field]', $field['field'], null, $data['filter']['inventories']),
+			(new CSelect('filter_inventory['.$i.'][field]'))
+				->setValue($field['field'])
+				->addOptions(CSelect::createOptionsFromArray($data['filter']['inventories'])),
 			(new CTextBox('filter_inventory['.$i.'][value]', $field['value']))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
 			(new CCol(
 				(new CButton('filter_inventory['.$i.'][remove]', _('Remove')))
@@ -265,8 +283,8 @@ if ($data['action'] == 'problem.view') {
 				->addValue(PROBLEMS_SHOW_TAGS_3, PROBLEMS_SHOW_TAGS_3)
 				->setModern(true)
 		)
-		->addItem((new CDiv())->setWidth(ZBX_STYLE_FORM_INPUT_MARGIN))
-		->addItem(_('Tag name'))
+		->addItem((new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN))
+		->addItem(new CLabel(_('Tag name')))
 		->addItem((new CRadioButtonList('filter_tag_name_format', (int) $data['filter']['tag_name_format']))
 				->addValue(_('Full'), PROBLEMS_TAG_NAME_FULL)
 				->addValue(_('Shortened'), PROBLEMS_TAG_NAME_SHORTENED)
@@ -285,6 +303,14 @@ if ($data['action'] == 'problem.view') {
 				->setAttribute('placeholder', _('comma-separated list'))
 				->setEnabled((int) $data['filter']['show_tags'] !== PROBLEMS_SHOW_TAGS_NONE)
 		)
+		->addRow(_('Show operational data'), [
+			(new CRadioButtonList('filter_show_opdata', (int) $data['filter']['show_opdata']))
+				->addValue(_('None'), OPERATIONAL_DATA_SHOW_NONE)
+				->addValue(_('Separately'), OPERATIONAL_DATA_SHOW_SEPARATELY)
+				->addValue(_('With problem name'), OPERATIONAL_DATA_SHOW_WITH_PROBLEM)
+				->setModern(true)
+				->setEnabled($data['filter']['compact_view'] == 0)
+		])
 		->addRow(_('Show suppressed problems'), [
 			(new CCheckBox('filter_show_suppressed'))
 				->setChecked($data['filter']['show_suppressed'] == ZBX_PROBLEM_SUPPRESSED_TRUE),
@@ -301,7 +327,7 @@ if ($data['action'] == 'problem.view') {
 				(new CLabel(_('Show timeline'), 'filter_show_timeline'))->addClass(ZBX_STYLE_SECOND_COLUMN_LABEL),
 				(new CCheckBox('filter_show_timeline'))
 					->setChecked($data['filter']['show_timeline'] == 1)
-					->setEnabled($data['filter']['compact_view'] == 0),
+					->setEnabled($data['filter']['compact_view'] == 0)
 			]))->addClass(ZBX_STYLE_TABLE_FORMS_SECOND_COLUMN)
 		])
 		->addRow(_('Show details'), [
@@ -318,11 +344,10 @@ if ($data['action'] == 'problem.view') {
 				->addClass(ZBX_STYLE_TABLE_FORMS_SECOND_COLUMN)
 		]);
 
-	$filter = (new CFilter())
+	$filter = (new CFilter((new CUrl('zabbix.php'))->setArgument('action', 'problem.view')))
 		->setProfile($data['profileIdx'])
 		->setActiveTab($data['active_tab'])
-		->addFormItem((new CVar('action', 'problem.view'))->removeId())
-		->addFormItem((new CVar('page', $data['page']))->removeId());
+		->addFormItem((new CVar('action', 'problem.view'))->removeId());
 
 	if ($data['filter']['show'] == TRIGGERS_OPTION_ALL) {
 		$filter->addTimeSelector($screen->timeline['from'], $screen->timeline['to']);
@@ -330,29 +355,20 @@ if ($data['action'] == 'problem.view') {
 
 	$filter->addFilterTab(_('Filter'), [$filter_column1, $filter_column2]);
 
-	$web_layout_mode = CView::getLayoutMode();
-
 	$widget = (new CWidget())
 		->setTitle(_('Problems'))
 		->setWebLayoutMode($web_layout_mode)
-		->setControls((new CTag('nav', true,
-			(new CForm('get'))
-				->cleanItems()
-				->addVar('action', 'problem.view')
-				->addVar('page', $data['page'])
-				->addItem((new CList())
+		->setControls(
+			(new CTag('nav', true,
+				(new CList())
 					->addItem(new CRedirectButton(_('Export to CSV'),
-						(new CUrl('zabbix.php'))
-							->setArgument('action', 'problem.view.csv')
-							->setArgument('page',  $data['page'])
+						(new CUrl('zabbix.php'))->setArgument('action', 'problem.view.csv')
 					))
-					->addItem(get_icon('fullscreen'))
-				)
-			))
-				->setAttribute('aria-label', _('Content controls'))
+					->addItem(get_icon('kioskmode', ['mode' => $web_layout_mode]))
+			))->setAttribute('aria-label', _('Content controls'))
 		);
 
-	if (in_array($web_layout_mode, [ZBX_LAYOUT_NORMAL, ZBX_LAYOUT_FULLSCREEN])) {
+	if ($web_layout_mode == ZBX_LAYOUT_NORMAL) {
 		$widget->addItem($filter);
 	}
 
@@ -360,8 +376,8 @@ if ($data['action'] == 'problem.view') {
 		->addItem($screen->get())
 		->show();
 
-	// activating blinking
-	$this->addPostJS('jqBlink.blink();');
+	// Activate blinking.
+	(new CScriptTag('jqBlink.blink();'))->show();
 
 	if ($data['filter']['show'] == TRIGGERS_OPTION_ALL) {
 		$objData = [
@@ -372,9 +388,10 @@ if ($data['action'] == 'problem.view') {
 			'mainObject' => 1
 		];
 
-		$this->addPostJS('timeControl.useTimeRefresh('.zbx_jsvalue(CWebUser::getRefresh()).');');
-		$this->addPostJS('timeControl.addObject("scroll_events_id", '.zbx_jsvalue($screen->timeline).', '.zbx_jsvalue($objData).');');
-		$this->addPostJS('timeControl.processObjects();');
+		(new CScriptTag(
+			'timeControl.addObject("scroll_events_id", '.zbx_jsvalue($screen->timeline).', '.zbx_jsvalue($objData).');'.
+			'timeControl.processObjects();'
+		))->show();
 	}
 }
 else {
