@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 // indicator of sort field
 $sort_div = (new CSpan())->addClass(ZBX_STYLE_ARROW_UP);
 
@@ -28,11 +32,10 @@ $table = (new CTableInfo())
 
 $url = (new CUrl('zabbix.php'))
 	->setArgument('action', 'web.view')
-	->setArgument('groupid', '')
-	->setArgument('hostid', '0');
+	->setArgument('filter_set', '1');
 
 foreach ($data['groups'] as $group) {
-	$url->setArgument('groupid', $group['groupid']);
+	$url->setArgument('filter_groupids', [$group['groupid']]);
 
 	$table->addRow([
 		new CLink($group['name'], $url->getUrl()),
@@ -56,4 +59,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
