@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -30,7 +30,9 @@ function condition_operator2str($operator) {
 		CONDITION_OPERATOR_LESS_EQUAL => _('is less than or equals'),
 		CONDITION_OPERATOR_NOT_IN => _('not in'),
 		CONDITION_OPERATOR_YES => _('Yes'),
-		CONDITION_OPERATOR_NO => _('No')
+		CONDITION_OPERATOR_NO => _('No'),
+		CONDITION_OPERATOR_REGEXP => _('matches'),
+		CONDITION_OPERATOR_NOT_REGEXP => _('does not match')
 	];
 
 	return $operators[$operator];
@@ -61,7 +63,7 @@ function condition_type2str($type) {
 		CONDITION_TYPE_PROXY => _('Proxy'),
 		CONDITION_TYPE_EVENT_TYPE => _('Event type'),
 		CONDITION_TYPE_HOST_METADATA => _('Host metadata'),
-		CONDITION_TYPE_EVENT_TAG => _('Tag'),
+		CONDITION_TYPE_EVENT_TAG => _('Tag name'),
 		CONDITION_TYPE_EVENT_TAG_VALUE => _('Tag value')
 	];
 
@@ -86,7 +88,7 @@ function discovery_object2str($object = null) {
  *
  * For action condition types such as: hosts, host groups, templates, proxies, triggers, discovery rules
  * and discovery checks, action condition values contain IDs. All unique IDs are first collected and then queried.
- * For other action condition types values are returned as they are or converted using simple string convertion
+ * For other action condition types values are returned as they are or converted using simple string conversion
  * functions according to action condition type.
  *
  * @param array $actions							array of actions
@@ -316,29 +318,6 @@ function actionConditionValueToString(array $actions, array $config) {
 	return $result;
 }
 
-/**
- * Converts numerical action operation condition values to their corresponding string values according to
- * action operation condition type. Since action list does not display operation conditions,
- * so there is only an array of operation conditions for single action which is displayed in operation details.
- *
- * @param array  $conditions					array of actions operation conditions
- * @param string $condition['conditiontype']	operation condition type
- * @param string $condition['value']			operation condition value
- *
- * @return array								returns an array of action operation condition string values
- */
-function actionOperationConditionValueToString(array $conditions) {
-	$result = [];
-
-	foreach ($conditions as $condition) {
-		if ($condition['conditiontype'] == CONDITION_TYPE_EVENT_ACKNOWLEDGED) {
-			$result[] = $condition['value'] ? _('Ack') : _('Not Ack');
-		}
-	}
-
-	return $result;
-}
-
 /**
  * Returns the HTML representation of an action condition and action operation condition.
  *
@@ -351,7 +330,7 @@ function actionOperationConditionValueToString(array $conditions) {
  */
 function getConditionDescription($condition_type, $operator, $value, $value2) {
 	if ($condition_type == CONDITION_TYPE_EVENT_TAG_VALUE) {
-		$description = [_('Tag')];
+		$description = [_('Value of tag')];
 		$description[] = ' ';
 		$description[] = italic(CHtml::encode($value2));
 		$description[] = ' ';
@@ -361,6 +340,9 @@ function getConditionDescription($condition_type, $operator, $value, $value2) {
 			? [_('Problem is suppressed')]
 			: [_('Problem is not suppressed')];
 	}
+	elseif ($condition_type == CONDITION_TYPE_EVENT_ACKNOWLEDGED) {
+		return $value ? _('Event is acknowledged') : _('Event is not acknowledged');
+	}
 	else {
 		$description = [condition_type2str($condition_type)];
 		$description[] = ' ';
@@ -438,15 +420,15 @@ function getActionOperationDescriptions(array $actions, $type) {
 
 					case OPERATION_TYPE_GROUP_ADD:
 					case OPERATION_TYPE_GROUP_REMOVE:
-						foreach ($operation['groupids'] as $groupid) {
-							$groupids[$groupid] = true;
+						foreach ($operation['opgroup'] as $groupid) {
+							$groupids[$groupid['groupid']] = true;
 						}
 						break;
 
 					case OPERATION_TYPE_TEMPLATE_ADD:
 					case OPERATION_TYPE_TEMPLATE_REMOVE:
-						foreach ($operation['templateids'] as $templateid) {
-							$templateids[$templateid] = true;
+						foreach ($operation['optemplate'] as $templateid) {
+							$templateids[$templateid['templateid']] = true;
 						}
 						break;
 				}
@@ -510,7 +492,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 
 	if ($media_typeids) {
 		$media_types = API::Mediatype()->get([
-			'output' => ['description'],
+			'output' => ['name'],
 			'mediatypeids' => $media_typeids,
 			'preservekeys' => true
 		]);
@@ -561,7 +543,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 		]);
 	}
 
-	// format the HTML ouput
+	// Format the HTML output.
 	foreach ($actions as $i => $action) {
 		if ($type == ACTION_OPERATION) {
 			foreach ($action['operations'] as $j => $operation) {
@@ -571,7 +553,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 						$media_typeid = $operation['opmessage']['mediatypeid'];
 
 						if ($media_typeid != 0 && isset($media_types[$media_typeid])) {
-							$media_type = $media_types[$media_typeid]['description'];
+							$media_type = $media_types[$media_typeid]['name'];
 						}
 
 						if (array_key_exists('opmessage_usr', $operation) && $operation['opmessage_usr']) {
@@ -671,9 +653,9 @@ function getActionOperationDescriptions(array $actions, $type) {
 					case OPERATION_TYPE_GROUP_REMOVE:
 						$host_group_list = [];
 
-						foreach ($operation['groupids'] as $groupid) {
-							if (array_key_exists($groupid, $host_groups)) {
-								$host_group_list[] = $host_groups[$groupid]['name'];
+						foreach ($operation['opgroup'] as $groupid) {
+							if (array_key_exists($groupid['groupid'], $host_groups)) {
+								$host_group_list[] = $host_groups[$groupid['groupid']]['name'];
 							}
 						}
 
@@ -693,9 +675,9 @@ function getActionOperationDescriptions(array $actions, $type) {
 					case OPERATION_TYPE_TEMPLATE_REMOVE:
 						$template_list = [];
 
-						foreach ($operation['templateids'] as $templateid) {
-							if (array_key_exists($templateid, $templates)) {
-								$template_list[] = $templates[$templateid]['name'];
+						foreach ($operation['optemplate'] as $templateid) {
+							if (array_key_exists($templateid['templateid'], $templates)) {
+								$template_list[] = $templates[$templateid['templateid']]['name'];
 							}
 						}
 
@@ -734,7 +716,7 @@ function getActionOperationDescriptions(array $actions, $type) {
 						$media_typeid = $operation['opmessage']['mediatypeid'];
 
 						if ($media_typeid != 0 && isset($media_types[$media_typeid])) {
-							$media_type = $media_types[$media_typeid]['description'];
+							$media_type = $media_types[$media_typeid]['name'];
 						}
 
 						if (array_key_exists('opmessage_usr', $operation) && $operation['opmessage_usr']) {
@@ -829,22 +811,18 @@ function getActionOperationDescriptions(array $actions, $type) {
 /**
  * Gathers action operation script details and returns the HTML items representing action operation with hint.
  *
- * @param array  $operations								Array of action operations or recovery operations.
- * @param string $operation['operationtype']				Action operation type.
- *															Possible values: OPERATION_TYPE_MESSAGE, OPERATION_TYPE_COMMAND,
- *															OPERATION_TYPE_ACK_MESSAGE and OPERATION_TYPE_RECOVERY_MESSAGE
- * @param string $operation['opcommand']['type']			Action operation command type.
- *															Possible values: ZBX_SCRIPT_TYPE_IPMI, ZBX_SCRIPT_TYPE_SSH,
- *															ZBX_SCRIPT_TYPE_TELNET, ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT
- *															and ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT
- * @param string $operation['opmessage']['default_msg']		'1' to show default message (optional)
- * @param array  $defaultMessage							Array containing default subject and message set via action.
- * @param string $defaultMessage['subject']					Default subject.
- * @param string $defaultMessage['message']					Default message text.
+ * @param array  $operations                      Array of action operations.
+ * @param string $operation['operationtype']      Action operation type.
+ *                                                Possible values: OPERATION_TYPE_MESSAGE, OPERATION_TYPE_COMMAND,
+ *                                                OPERATION_TYPE_ACK_MESSAGE and OPERATION_TYPE_RECOVERY_MESSAGE
+ * @param string $operation['opcommand']['type']  Action operation command type.
+ *                                                Possible values: ZBX_SCRIPT_TYPE_IPMI, ZBX_SCRIPT_TYPE_SSH,
+ *                                                ZBX_SCRIPT_TYPE_TELNET, ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT
+ *                                                and ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT
  *
- * @return array											Returns an array of action operation hints.
+ * @return array  Returns an array of action operation hints.
  */
-function getActionOperationHints(array $operations, array $defaultMessage) {
+function getActionOperationHints(array $operations) {
 	$result = [];
 	$scriptids = [];
 	$scripts = [];
@@ -867,107 +845,59 @@ function getActionOperationHints(array $operations, array $defaultMessage) {
 	foreach ($operations as $key => $operation) {
 		$result[$key] = [];
 
-		switch ($operation['operationtype']) {
-			case OPERATION_TYPE_MESSAGE:
-				// show default entered action subject and message or show custom subject and message for each operation
-				$subject = (isset($operation['opmessage']['default_msg']) && $operation['opmessage']['default_msg'])
-					? $defaultMessage['subject']
-					: $operation['opmessage']['subject'];
+		if ($operation['operationtype'] == OPERATION_TYPE_COMMAND) {
+			switch ($operation['opcommand']['type']) {
+				case ZBX_SCRIPT_TYPE_IPMI:
+					$result[$key][] = [bold(_('Run IPMI command').': '), BR(),
+						italic(zbx_nl2br($operation['opcommand']['command']))
+					];
+					break;
 
-				$message = (isset($operation['opmessage']['default_msg']) && $operation['opmessage']['default_msg'])
-					? $defaultMessage['message']
-					: $operation['opmessage']['message'];
+				case ZBX_SCRIPT_TYPE_SSH:
+					$result[$key][] = [bold(_('Run SSH commands').': '), BR(),
+						italic(zbx_nl2br($operation['opcommand']['command']))
+					];
+					break;
 
-				$result_hint = [];
+				case ZBX_SCRIPT_TYPE_TELNET:
+					$result[$key][] = [bold(_('Run TELNET commands').': '), BR(),
+						italic(zbx_nl2br($operation['opcommand']['command']))
+					];
+					break;
 
-				if (trim($subject)) {
-					$result_hint = [bold($subject), BR(), BR()];
-				}
-
-				if (trim($message)) {
-					$result_hint[] = zbx_nl2br($message);
-				}
-
-				if ($result_hint) {
-					$result[$key][] = $result_hint;
-				}
-				break;
-
-			case OPERATION_TYPE_COMMAND:
-				switch ($operation['opcommand']['type']) {
-					case ZBX_SCRIPT_TYPE_IPMI:
-						$result[$key][] = [bold(_('Run IPMI command').': '), BR(),
-							italic(zbx_nl2br($operation['opcommand']['command']))
+				case ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT:
+					if ($operation['opcommand']['execute_on'] == ZBX_SCRIPT_EXECUTE_ON_AGENT) {
+						$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix agent')).': '),
+							BR(), italic(zbx_nl2br($operation['opcommand']['command']))
 						];
-						break;
-
-					case ZBX_SCRIPT_TYPE_SSH:
-						$result[$key][] = [bold(_('Run SSH commands').': '), BR(),
-							italic(zbx_nl2br($operation['opcommand']['command']))
+					}
+					elseif ($operation['opcommand']['execute_on'] == ZBX_SCRIPT_EXECUTE_ON_PROXY) {
+						$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix server (proxy)')).': '),
+							BR(), italic(zbx_nl2br($operation['opcommand']['command']))
 						];
-						break;
-
-					case ZBX_SCRIPT_TYPE_TELNET:
-						$result[$key][] = [bold(_('Run TELNET commands').': '), BR(),
-							italic(zbx_nl2br($operation['opcommand']['command']))
+					}
+					else {
+						$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix server')).': '),
+							BR(), italic(zbx_nl2br($operation['opcommand']['command']))
 						];
-						break;
+					}
+					break;
 
-					case ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT:
-						if ($operation['opcommand']['execute_on'] == ZBX_SCRIPT_EXECUTE_ON_AGENT) {
-							$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix agent')).': '),
-								BR(), italic(zbx_nl2br($operation['opcommand']['command']))
-							];
-						}
-						elseif ($operation['opcommand']['execute_on'] == ZBX_SCRIPT_EXECUTE_ON_PROXY) {
-							$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix server (proxy)')).': '),
-								BR(), italic(zbx_nl2br($operation['opcommand']['command']))
-							];
-						}
-						else {
-							$result[$key][] = [bold(_s('Run custom commands on %1$s', _('Zabbix server')).': '),
-								BR(), italic(zbx_nl2br($operation['opcommand']['command']))
-							];
-						}
-						break;
+				case ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT:
+					$scriptId = $operation['opcommand']['scriptid'];
 
-					case ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT:
-						$scriptId = $operation['opcommand']['scriptid'];
-
-						if (isset($scripts[$scriptId])) {
-							$result[$key][] = [bold(_('Run global script').': '),
-								italic($scripts[$scriptId]['name'])
-							];
-						}
-						break;
-
-					default:
-						$result[$key][] = [bold(_('Run commands').': '), BR(),
-							italic(zbx_nl2br($operation['opcommand']['command']))
+					if (isset($scripts[$scriptId])) {
+						$result[$key][] = [bold(_('Run global script').': '),
+							italic($scripts[$scriptId]['name'])
 						];
-				}
-				break;
+					}
+					break;
 
-			case OPERATION_TYPE_ACK_MESSAGE:
-			case OPERATION_TYPE_RECOVERY_MESSAGE:
-				$result_hint = [];
-				$message = (array_key_exists('default_msg', $operation['opmessage'])
-					&& $operation['opmessage']['default_msg'])
-					? $defaultMessage
-					: $operation['opmessage'];
-
-				if (trim($message['subject'])) {
-					$result_hint = [bold($message['subject']), BR(), BR()];
-				}
-
-				if (trim($message['message'])) {
-					$result_hint[] = zbx_nl2br($message['message']);
-				}
-
-				if ($result_hint) {
-					$result[$key][] = $result_hint;
-				}
-				break;
+				default:
+					$result[$key][] = [bold(_('Run commands').': '), BR(),
+						italic(zbx_nl2br($operation['opcommand']['command']))
+					];
+			}
 		}
 	}
 
@@ -983,41 +913,41 @@ function getActionOperationHints(array $operations, array $defaultMessage) {
  */
 function get_conditions_by_eventsource($eventsource) {
 	$conditions[EVENT_SOURCE_TRIGGERS] = [
-		CONDITION_TYPE_APPLICATION,
-		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST,
-		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_NAME,
+		CONDITION_TYPE_TRIGGER,
 		CONDITION_TYPE_TRIGGER_SEVERITY,
-		CONDITION_TYPE_TIME_PERIOD,
+		CONDITION_TYPE_APPLICATION,
+		CONDITION_TYPE_HOST,
+		CONDITION_TYPE_HOST_GROUP,
 		CONDITION_TYPE_SUPPRESSED,
 		CONDITION_TYPE_EVENT_TAG,
-		CONDITION_TYPE_EVENT_TAG_VALUE
+		CONDITION_TYPE_EVENT_TAG_VALUE,
+		CONDITION_TYPE_TEMPLATE,
+		CONDITION_TYPE_TIME_PERIOD
 	];
 	$conditions[EVENT_SOURCE_DISCOVERY] = [
 		CONDITION_TYPE_DHOST_IP,
-		CONDITION_TYPE_DSERVICE_TYPE,
-		CONDITION_TYPE_DSERVICE_PORT,
-		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DCHECK,
 		CONDITION_TYPE_DOBJECT,
+		CONDITION_TYPE_DRULE,
 		CONDITION_TYPE_DSTATUS,
-		CONDITION_TYPE_DUPTIME,
-		CONDITION_TYPE_DVALUE,
-		CONDITION_TYPE_PROXY
-	];
-	$conditions[EVENT_SOURCE_AUTO_REGISTRATION] = [
-		CONDITION_TYPE_HOST_NAME,
 		CONDITION_TYPE_PROXY,
-		CONDITION_TYPE_HOST_METADATA
+		CONDITION_TYPE_DVALUE,
+		CONDITION_TYPE_DSERVICE_PORT,
+		CONDITION_TYPE_DSERVICE_TYPE,
+		CONDITION_TYPE_DUPTIME
+	];
+	$conditions[EVENT_SOURCE_AUTOREGISTRATION] = [
+		CONDITION_TYPE_HOST_NAME,
+		CONDITION_TYPE_HOST_METADATA,
+		CONDITION_TYPE_PROXY
 	];
 	$conditions[EVENT_SOURCE_INTERNAL] = [
 		CONDITION_TYPE_APPLICATION,
 		CONDITION_TYPE_EVENT_TYPE,
+		CONDITION_TYPE_HOST,
 		CONDITION_TYPE_HOST_GROUP,
-		CONDITION_TYPE_TEMPLATE,
-		CONDITION_TYPE_HOST
+		CONDITION_TYPE_TEMPLATE
 	];
 
 	if (isset($conditions[$eventsource])) {
@@ -1030,7 +960,7 @@ function get_conditions_by_eventsource($eventsource) {
 function get_opconditions_by_eventsource($eventsource) {
 	$conditions = [
 		EVENT_SOURCE_TRIGGERS => [CONDITION_TYPE_EVENT_ACKNOWLEDGED],
-		EVENT_SOURCE_DISCOVERY => [],
+		EVENT_SOURCE_DISCOVERY => []
 	];
 
 	if (isset($conditions[$eventsource])) {
@@ -1081,7 +1011,7 @@ function getAllowedOperations($eventsource) {
 		];
 	}
 
-	if ($eventsource == EVENT_SOURCE_AUTO_REGISTRATION) {
+	if ($eventsource == EVENT_SOURCE_AUTOREGISTRATION) {
 		$operations[ACTION_OPERATION] = [
 			OPERATION_TYPE_MESSAGE,
 			OPERATION_TYPE_COMMAND,
@@ -1223,7 +1153,7 @@ function get_operators_by_conditiontype($conditiontype) {
 		CONDITION_OPERATOR_NOT_EQUAL
 	];
 	$operators[CONDITION_TYPE_DOBJECT] = [
-		CONDITION_OPERATOR_EQUAL,
+		CONDITION_OPERATOR_EQUAL
 	];
 	$operators[CONDITION_TYPE_PROXY] = [
 		CONDITION_OPERATOR_EQUAL,
@@ -1242,7 +1172,7 @@ function get_operators_by_conditiontype($conditiontype) {
 		CONDITION_OPERATOR_NOT_EQUAL
 	];
 	$operators[CONDITION_TYPE_DSTATUS] = [
-		CONDITION_OPERATOR_EQUAL,
+		CONDITION_OPERATOR_EQUAL
 	];
 	$operators[CONDITION_TYPE_DUPTIME] = [
 		CONDITION_OPERATOR_MORE_EQUAL,
@@ -1266,14 +1196,18 @@ function get_operators_by_conditiontype($conditiontype) {
 	];
 	$operators[CONDITION_TYPE_HOST_NAME] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TYPE] = [
 		CONDITION_OPERATOR_EQUAL
 	];
 	$operators[CONDITION_TYPE_HOST_METADATA] = [
 		CONDITION_OPERATOR_LIKE,
-		CONDITION_OPERATOR_NOT_LIKE
+		CONDITION_OPERATOR_NOT_LIKE,
+		CONDITION_OPERATOR_REGEXP,
+		CONDITION_OPERATOR_NOT_REGEXP
 	];
 	$operators[CONDITION_TYPE_EVENT_TAG] = [
 		CONDITION_OPERATOR_EQUAL,
@@ -1727,7 +1661,7 @@ function getEventUpdates(array $event) {
  * @param array  $actions['messages']    Messages icon data.
  * @param array  $actions['severities']  Severity change icon data.
  * @param array  $actions['actions']     Actions icon data.
- * @param array  $mediatypes             Mediatypes with maxattempts value and description.
+ * @param array  $mediatypes             Mediatypes with maxattempts value and name.
  * @param array  $users                  User name, surname and alias.
  * @param array  $config                 Zabbix config.
  *
@@ -1888,8 +1822,8 @@ function makeEventSeverityChangesIcon(array $data, array $users, array $config)
  * @param bool   $data['has_uncomplete_action']     Does the event have at least one uncompleted alert action.
  * @param bool   $data['has_failed_action']         Does the event have at least one failed alert action.
  * @param array  $users                             User name, surname and alias.
- * @param array  $mediatypes                        Mediatypes with maxattempts value and description.
- * @param string $mediatypes[]['description']       Mediatype description.
+ * @param array  $mediatypes                        Mediatypes with maxattempts value and name.
+ * @param string $mediatypes[]['name']              Mediatype name.
  * @param array  $config                            Zabbix config.
  *
  * @return CSpan|null
@@ -1918,7 +1852,7 @@ function makeEventActionsIcon(array $data, array $users, array $mediatypes, arra
 			}
 			elseif ($action['alerttype'] == ALERT_TYPE_MESSAGE) {
 				$message = array_key_exists($action['mediatypeid'], $mediatypes)
-					? $mediatypes[$action['mediatypeid']]['description']
+					? $mediatypes[$action['mediatypeid']]['name']
 					: '';
 			}
 		}
@@ -2035,7 +1969,9 @@ function makeEventDetailsActionsTable(array $data, array $users, array $mediatyp
  * @return CTable
  */
 function makeEventHistoryTable(array $actions, array $users, array $config) {
-	$table = (new CTable())->setHeader([_('Time'), _('User'), _('User action'), _('Message')]);
+	$table = (new CTable())
+		->addStyle('width: 100%;')
+		->setHeader([_('Time'), _('User'), _('User action'), _('Message')]);
 
 	foreach ($actions as $action) {
 		// Added in order to reuse makeActionTableUser() and makeActionTableIcon()
@@ -2045,7 +1981,7 @@ function makeEventHistoryTable(array $actions, array $users, array $config) {
 			zbx_date2str(DATE_TIME_FORMAT_SECONDS, $action['clock']),
 			makeActionTableUser($action, $users),
 			makeActionTableIcon($action, $config),
-			zbx_nl2br($action['message'])
+			(new CCol(zbx_nl2br($action['message'])))->addClass(ZBX_STYLE_TABLE_FORMS_OVERFLOW_BREAK)
 		]);
 	}
 
@@ -2138,6 +2074,10 @@ function makeActionTableIcon(array $action, array $config) {
 				$action_icons[] = makeActionIcon(['icon' => ZBX_STYLE_ACTION_ICON_ACK, 'title' => _('Acknowledged')]);
 			}
 
+			if (($action['action'] & ZBX_PROBLEM_UPDATE_UNACKNOWLEDGE) == ZBX_PROBLEM_UPDATE_UNACKNOWLEDGE) {
+				$action_icons[] = makeActionIcon(['icon' => ZBX_STYLE_ACTION_ICON_UNACK, 'title' => _('Unacknowledged')]);
+			}
+
 			if (($action['action'] & ZBX_PROBLEM_UPDATE_MESSAGE) == ZBX_PROBLEM_UPDATE_MESSAGE) {
 				$action_icons[] = makeActionIcon(['icon' => ZBX_STYLE_ACTION_ICON_MSG, 'title' => _('Message')]);
 			}
