@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -140,7 +140,7 @@ class CAlert extends CApiService {
 
 		// Oracle does not support using distinct with nclob fields, so we must use exists instead of joins
 		if ($options['eventsource'] == EVENT_SOURCE_TRIGGERS
-				|| $options['eventsource'] == EVENT_SOURCE_AUTO_REGISTRATION) {
+				|| $options['eventsource'] == EVENT_SOURCE_AUTOREGISTRATION) {
 			/*
 			 * Performance optimization: events with such sources does not have multiple objects therefore we can ignore
 			 * event object in SQL requests.
@@ -293,9 +293,18 @@ class CAlert extends CApiService {
 
 		// search
 		if (is_array($options['search'])) {
+			unset($options['search']['parameters']);
 			zbx_db_search('alerts a', $options, $sqlParts);
 		}
 
+		if (!$options['countOutput'] && $this->outputIsRequested('parameters', $options['output'])) {
+			$fields = ($options['output'] === API_OUTPUT_EXTEND)
+				? $this->getTableSchema()['fields']
+				: array_flip($options['output']);
+			unset($fields['parameters']);
+			$options['output'] = array_keys($fields);
+		}
+
 		// time_from
 		if (!is_null($options['time_from'])) {
 			$sqlParts['where'][] = 'a.clock>'.zbx_dbstr($options['time_from']);
@@ -313,7 +322,7 @@ class CAlert extends CApiService {
 
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$dbRes = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$dbRes = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($alert = DBfetch($dbRes)) {
 			if ($options['countOutput']) {
 				$result = $alert['rowscount'];
