@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -519,27 +519,27 @@ class CTrigger extends CTriggerGeneral {
 	 * @return array
 	 */
 	public function create(array $triggers) {
-		$triggers = zbx_toArray($triggers);
-
 		$this->validateCreate($triggers);
 		$this->createReal($triggers);
 		$this->inherit($triggers);
 
-		// clear all dependencies on inherited triggers
+		// Clear all dependencies on inherited triggers.
 		$this->deleteDependencies($triggers);
 
-		// add new dependencies
+		// Add new dependencies.
 		foreach ($triggers as $trigger) {
-			if (!empty($trigger['dependencies'])) {
-				$newDeps = [];
-				foreach ($trigger['dependencies'] as $depTrigger) {
-					$newDeps[] = [
-						'triggerid' => $trigger['triggerid'],
-						'dependsOnTriggerid' => $depTrigger['triggerid']
-					];
-				}
-				$this->addDependencies($newDeps);
+			if (!array_key_exists('dependencies', $trigger) || !$trigger['dependencies']) {
+				continue;
 			}
+
+			$new_dependencies = [];
+			foreach ($trigger['dependencies'] as $dependency) {
+				$new_dependencies[] = [
+					'triggerid' => $trigger['triggerid'],
+					'dependsOnTriggerid' => $dependency['triggerid']
+				];
+			}
+			$this->addDependencies($new_dependencies);
 		}
 
 		return ['triggerids' => zbx_objectValues($triggers, 'triggerid')];
@@ -555,8 +555,6 @@ class CTrigger extends CTriggerGeneral {
 	 * @return array
 	 */
 	public function update(array $triggers) {
-		$triggers = zbx_toArray($triggers);
-
 		$this->validateUpdate($triggers, $db_triggers);
 
 		$validate_dependencies = [];
@@ -564,7 +562,7 @@ class CTrigger extends CTriggerGeneral {
 			$db_trigger = $db_triggers[$tnum];
 
 			$expressions_changed = ($trigger['expression'] !== $db_trigger['expression']
-				|| $trigger['recovery_expression'] !== $db_trigger['recovery_expression']);
+					|| $trigger['recovery_expression'] !== $db_trigger['recovery_expression']);
 
 			if ($expressions_changed && $db_trigger['dependencies'] && !array_key_exists('dependencies', $trigger)) {
 				$validate_dependencies[] = [
@@ -583,19 +581,19 @@ class CTrigger extends CTriggerGeneral {
 		$this->inherit($triggers);
 
 		foreach ($triggers as $trigger) {
-			// replace dependencies
+			// Replace dependencies.
 			if (array_key_exists('dependencies', $trigger)) {
 				$this->deleteDependencies($trigger);
 
 				if ($trigger['dependencies']) {
-					$newDeps = [];
-					foreach ($trigger['dependencies'] as $depTrigger) {
-						$newDeps[] = [
+					$new_dependencies = [];
+					foreach ($trigger['dependencies'] as $dependency) {
+						$new_dependencies[] = [
 							'triggerid' => $trigger['triggerid'],
-							'dependsOnTriggerid' => $depTrigger['triggerid']
+							'dependsOnTriggerid' => $dependency['triggerid']
 						];
 					}
-					$this->addDependencies($newDeps);
+					$this->addDependencies($new_dependencies);
 				}
 			}
 		}
@@ -663,17 +661,22 @@ class CTrigger extends CTriggerGeneral {
 	/**
 	 * Validates the input for the addDependencies() method.
 	 *
-	 * @throws APIException if the given dependencies are invalid
-	 *
-	 * @param array $triggersData
+	 * @param array $triggers_data
 	 * @param bool  $inherited
+	 *
+	 * @throws APIException if the given dependencies are invalid.
 	 */
-	protected function validateAddDependencies(array $triggersData, $inherited = false) {
-		if (!$triggersData) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+	protected function validateAddDependencies(array &$triggers_data, $inherited = false) {
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['triggerid', 'dependsOnTriggerid']], 'fields' => [
+			'triggerid' =>			['type' => API_ID, 'flags' => API_REQUIRED],
+			'dependsOnTriggerid' =>	['type' => API_ID, 'flags' => API_REQUIRED]
+		]];
+		if (!CApiInputValidator::validate($api_input_rules, $triggers_data, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		$triggerids = array_unique(zbx_objectValues($triggersData, 'triggerid'));
+		$triggerids = zbx_objectValues($triggers_data, 'triggerid');
+		$triggerids = array_keys(array_flip($triggerids));
 
 		$permission_check = $inherited
 			? ['nopermissions' => true]
@@ -685,12 +688,8 @@ class CTrigger extends CTriggerGeneral {
 			'preservekeys' => true
 		] + $permission_check);
 
-		foreach ($triggerids as $triggerid) {
-			if (!array_key_exists($triggerid, $triggers)) {
-				self::exception(ZBX_API_ERROR_PERMISSIONS,
-					_('No permissions to referred object or it does not exist!')
-				);
-			}
+		if (count($triggerids) != count($triggers)) {
+			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
 		}
 
 		foreach ($triggers as $trigger) {
@@ -701,28 +700,28 @@ class CTrigger extends CTriggerGeneral {
 			}
 		}
 
-		$depTtriggerIds = [];
+		$dep_triggerids = [];
 		$triggers = [];
-		foreach ($triggersData as $dep) {
-			$triggerId = $dep['triggerid'];
+		foreach ($triggers_data as $dep) {
+			$triggerid = $dep['triggerid'];
 
-			if (!isset($triggers[$dep['triggerid']])) {
-				$triggers[$triggerId] = [
-					'triggerid' => $triggerId,
-					'dependencies' => [],
+			if (!array_key_exists($dep['triggerid'], $triggers)) {
+				$triggers[$triggerid] = [
+					'triggerid' => $triggerid,
+					'dependencies' => []
 				];
 			}
-			$triggers[$triggerId]['dependencies'][] = $dep['dependsOnTriggerid'];
-			$depTtriggerIds[$dep['dependsOnTriggerid']] = $dep['dependsOnTriggerid'];
+			$triggers[$triggerid]['dependencies'][] = $dep['dependsOnTriggerid'];
+			$dep_triggerids[$dep['dependsOnTriggerid']] = $dep['dependsOnTriggerid'];
 		}
 
-		if (!$inherited && $depTtriggerIds) {
+		if (!$inherited) {
 			$count = $this->get([
 				'countOutput' => true,
-				'triggerids' => $depTtriggerIds
+				'triggerids' => $dep_triggerids
 			]);
 
-			if ($count != count($depTtriggerIds)) {
+			if ($count != count($dep_triggerids)) {
 				self::exception(ZBX_API_ERROR_PERMISSIONS,
 					_('No permissions to referred object or it does not exist!')
 				);
@@ -737,19 +736,17 @@ class CTrigger extends CTriggerGeneral {
 	/**
 	 * Add the given dependencies and inherit them on all child triggers.
 	 *
-	 * @param array $triggersData   an array of trigger dependency pairs, each pair in the form of
-	 *                              array('triggerid' => 1, 'dependsOnTriggerid' => 2)
+	 * @param array $triggers_data  An array of trigger dependency pairs, each pair in the form of
+	 *                              ['triggerid' => 1, 'dependsOnTriggerid' => 2].
 	 * @param bool  $inherited      Determines either to check permissions for added dependencies. Permissions are not
 	 *                              validated for inherited triggers.
 	 *
 	 * @return array
 	 */
-	public function addDependencies(array $triggersData, $inherited = false) {
-		$triggersData = zbx_toArray($triggersData);
+	public function addDependencies(array $triggers_data, $inherited = false) {
+		$this->validateAddDependencies($triggers_data, $inherited);
 
-		$this->validateAddDependencies($triggersData, $inherited);
-
-		foreach ($triggersData as $dep) {
+		foreach ($triggers_data as $dep) {
 			$triggerId = $dep['triggerid'];
 			$depTriggerId = $dep['dependsOnTriggerid'];
 
@@ -781,23 +778,24 @@ class CTrigger extends CTriggerGeneral {
 			}
 		}
 
-		return ['triggerids' => array_unique(zbx_objectValues($triggersData, 'triggerid'))];
+		return ['triggerids' => array_unique(zbx_objectValues($triggers_data, 'triggerid'))];
 	}
 
 	/**
 	 * Validates the input for the deleteDependencies() method.
 	 *
-	 * @throws APIException if the given input is invalid
-	 *
 	 * @param array $triggers
 	 * @param bool  $inherited
+	 *
+	 * @throws APIException if the given input is invalid
 	 */
 	protected function validateDeleteDependencies(array $triggers, $inherited) {
 		if (!$triggers) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
 		}
 
-		$triggerids = array_unique(zbx_objectValues($triggers, 'triggerid'));
+		$triggerids = zbx_objectValues($triggers, 'triggerid');
+		$triggerids = array_keys(array_flip($triggerids));
 
 		$permission_check = $inherited
 			? ['nopermissions' => true]
@@ -999,7 +997,7 @@ class CTrigger extends CTriggerGeneral {
 			$triggerDependencyTemplates = API::Template()->get([
 				'output' => ['templateid'],
 				'triggerids' => $trigger['dependencies'],
-				'nopermissions' => true,
+				'nopermissions' => true
 			]);
 			$depTemplateIds = zbx_toHash(zbx_objectValues($triggerDependencyTemplates, 'templateid'));
 
@@ -1206,7 +1204,7 @@ class CTrigger extends CTriggerGeneral {
 				'output' => $options['selectDiscoveryRule'],
 				'itemids' => $relationMap->getRelatedIds(),
 				'nopermissions' => true,
-				'preservekeys' => true,
+				'preservekeys' => true
 			]);
 			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
 		}
