@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -277,26 +277,6 @@ class DB {
 		return $schema['fields'][$field_name]['length'];
 	}
 
-	private static function addMissingFields($tableSchema, $values) {
-		global $DB;
-
-		if ($DB['TYPE'] == ZBX_DB_MYSQL) {
-			foreach ($tableSchema['fields'] as $name => $field) {
-				if (($field['type'] == self::FIELD_TYPE_TEXT || $field['type'] == self::FIELD_TYPE_NCLOB)
-						&& !$field['null']) {
-					foreach ($values as &$value) {
-						if (!isset($value[$name])) {
-							$value[$name] = '';
-						}
-					}
-					unset($value);
-				}
-			}
-		}
-
-		return $values;
-	}
-
 	public static function getDefaults($table) {
 		$table = self::getSchema($table);
 
@@ -324,9 +304,8 @@ class DB {
 		return isset($field['default']) ? $field['default'] : null;
 	}
 
-	public static function checkValueTypes($table, &$values) {
+	private static function checkValueTypes($tableSchema, &$values) {
 		global $DB;
-		$tableSchema = self::getSchema($table);
 
 		foreach ($values as $field => $value) {
 			if (!isset($tableSchema['fields'][$field])) {
@@ -471,38 +450,60 @@ class DB {
 	 * @return array    an array of ids with the keys preserved
 	 */
 	public static function insert($table, $values, $getids = true) {
-		if (empty($values)) {
-			return true;
-		}
-
-		$resultIds = [];
-
-		if ($getids) {
-			$id = self::reserveIds($table, count($values));
-		}
-
-		$tableSchema = self::getSchema($table);
-
-		$values = self::addMissingFields($tableSchema, $values);
+		$table_schema = self::getSchema($table);
+		$fields = [];
 
 		foreach ($values as $key => $row) {
-			if ($getids) {
-				$resultIds[$key] = $id;
-				$row[$tableSchema['key']] = $id;
-				$id = bcadd($id, 1, 0);
+			$fields += array_diff_key($row, $fields);
+		}
+
+		$fields = array_intersect_key($fields, $table_schema['fields']);
+
+		foreach ($fields as $field => &$value) {
+			$value = array_key_exists('default', $table_schema['fields'][$field])
+				? $table_schema['fields'][$field]['default']
+				: null;
+		}
+		unset($value);
+
+		foreach ($values as $key => &$row) {
+			$row += $fields;
+
+			$ordered_row = [];
+			foreach ($fields as $field => $foo) {
+				$ordered_row[$field] = $row[$field];
 			}
 
-			self::checkValueTypes($table, $row);
+			$row = $ordered_row;
+		}
+		unset($row);
 
-			$sql = 'INSERT INTO '.$table.' ('.implode(',', array_keys($row)).')'.
-					' VALUES ('.implode(',', array_values($row)).')';
+		return self::insertBatch($table, $values, $getids);
+	}
 
-			if (!DBexecute($sql)) {
-				self::exception(self::DBEXECUTE_ERROR, _s('SQL statement execution has failed "%1$s".', $sql));
+	/**
+	 * Returns the list of mandatory fields with default values for INSERT statements.
+	 *
+	 * @static
+	 *
+	 * @param array $table_schema
+	 *
+	 * @return array
+	 */
+	private static function getMandatoryFields(array $table_schema): array {
+		global $DB;
+
+		$mandatory_fields = [];
+
+		if ($DB['TYPE'] == ZBX_DB_MYSQL) {
+			foreach ($table_schema['fields'] as $name => $field) {
+				if ($field['type'] == self::FIELD_TYPE_TEXT || $field['type'] == self::FIELD_TYPE_NCLOB) {
+					$mandatory_fields += [$name => $field['default']];
+				}
 			}
 		}
 
-		return $resultIds;
+		return $mandatory_fields;
 	}
 
 	/**
@@ -521,28 +522,28 @@ class DB {
 
 		$resultIds = [];
 
-		$tableSchema = self::getSchema($table);
-		$values = self::addMissingFields($tableSchema, $values);
+		$table_schema = self::getSchema($table);
 
 		if ($getids) {
 			$id = self::reserveIds($table, count($values));
 		}
 
-		$newValues = [];
-		foreach ($values as $key => $row) {
+		$mandatory_fields = self::getMandatoryFields($table_schema);
+
+		foreach ($values as $key => &$row) {
 			if ($getids) {
 				$resultIds[$key] = $id;
-				$row[$tableSchema['key']] = $id;
-				$values[$key][$tableSchema['key']] = $id;
+				$row[$table_schema['key']] = $id;
 				$id = bcadd($id, 1, 0);
 			}
-			self::checkValueTypes($table, $row);
-			$newValues[] = $row;
+
+			$row += $mandatory_fields;
+
+			self::checkValueTypes($table_schema, $row);
 		}
+		unset($row);
 
-		$fields = array_keys(reset($newValues));
-
-		$sql = self::getDbBackend()->createInsertQuery($table, $fields, $newValues);
+		$sql = self::getDbBackend()->createInsertQuery($table, array_keys(reset($values)), $values);
 
 		if (!DBexecute($sql)) {
 			self::exception(self::DBEXECUTE_ERROR, _s('SQL statement execution has failed "%1$s".', $sql));
@@ -571,7 +572,7 @@ class DB {
 		$data = zbx_toArray($data);
 		foreach ($data as $row) {
 			// check
-			self::checkValueTypes($table, $row['values']);
+			self::checkValueTypes($tableSchema, $row['values']);
 			if (empty($row['values'])) {
 				self::exception(self::DBEXECUTE_ERROR, _s('Cannot perform update statement on table "%1$s" without values.', $table));
 			}
