@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -805,7 +805,7 @@ class CConfigurationExportBuilder {
 
 		foreach ($groupLinks as $groupLink) {
 			$result[] = [
-				'group' => $groupLink['groupid'],
+				'group' => $groupLink['groupid']
 			];
 		}
 
