@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -132,7 +132,13 @@ class CXmlExportWriter extends CExportWriter {
 			'posts' => 'post_field',
 			'shapes' => 'shape',
 			'lines' => 'line',
-			'headers' => 'header'
+			'lld_macro_paths' => 'lld_macro_path',
+			'tls_accept' => 'option',
+			'media_types' => 'media_type',
+			'parameters' => 'parameter',
+			'message_templates' => 'message_template',
+			'overrides' => 'override',
+			'operations' => 'operation'
 		];
 
 		return isset($map[$name]) ? $map[$name] : false;
