@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -115,7 +115,11 @@ class CRadioButtonList extends CList {
 		}
 
 		if ($this->readonly) {
-			$this->addItem(new CVar($this->name, $this->value, zbx_formatDomId($this->name)));
+			$this->addItem(
+				(new CVar($this->name, $this->value))
+					->setEnabled($this->enabled)
+					->removeId()
+			);
 		}
 
 		foreach ($this->values as $key => $value) {
