@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -125,6 +125,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		// Min value on left Y axis.
 		$field_lefty_min = (new CWidgetFieldNumericBox('lefty_min', _('Min')))
 			->setPlaceholder(_('calculated'))
+			->setFullName(_('Left Y').'/'._('Min'))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 
 		if ($field_lefty->getValue() != SVG_GRAPH_AXIS_SHOW) {
@@ -139,6 +140,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		// Max value on left Y axis.
 		$field_lefty_max = (new CWidgetFieldNumericBox('lefty_max', _('Max')))
 			->setPlaceholder(_('calculated'))
+			->setFullName(_('Left Y').'/'._('Max'))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 
 		if ($field_lefty->getValue() != SVG_GRAPH_AXIS_SHOW) {
@@ -151,14 +153,11 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_lefty_max->getName()] = $field_lefty_max;
 
 		// Specify the type of units on left Y axis.
-		$field_lefty_units = (new CWidgetFieldComboBox('lefty_units', _('Units'), [
+		$field_lefty_units = (new CWidgetFieldSelect('lefty_units', _('Units'), [
 			SVG_GRAPH_AXIS_UNITS_AUTO => _x('Auto', 'history source selection method'),
 			SVG_GRAPH_AXIS_UNITS_STATIC => _x('Static', 'history source selection method')
 		]))
-			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO)
-			->setAction('jQuery("#lefty_static_units")'.
-							'.prop("disabled", (jQuery(this).val() != "'.SVG_GRAPH_AXIS_UNITS_STATIC.'"))'
-			);
+			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO);
 
 		if ($field_lefty->getValue() != SVG_GRAPH_AXIS_SHOW) {
 			$field_lefty_units->setFlags(CWidgetField::FLAG_DISABLED);
@@ -198,6 +197,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		// Min value on right Y axis.
 		$field_righty_min = (new CWidgetFieldNumericBox('righty_min', _('Min')))
 			->setPlaceholder(_('calculated'))
+			->setFullName(_('Right Y').'/'._('Min'))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 
 		if ($field_righty->getValue() != SVG_GRAPH_AXIS_SHOW) {
@@ -212,6 +212,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		// Max value on right Y axis.
 		$field_righty_max = (new CWidgetFieldNumericBox('righty_max', _('Max')))
 			->setPlaceholder(_('calculated'))
+			->setFullName(_('Right Y').'/'._('Max'))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 
 		if ($field_righty->getValue() != SVG_GRAPH_AXIS_SHOW) {
@@ -224,14 +225,11 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_righty_max->getName()] = $field_righty_max;
 
 		// Specify the type of units on right Y axis.
-		$field_righty_units = (new CWidgetFieldComboBox('righty_units', _('Units'), [
+		$field_righty_units = (new CWidgetFieldSelect('righty_units', _('Units'), [
 			SVG_GRAPH_AXIS_UNITS_AUTO => _x('Auto', 'history source selection method'),
 			SVG_GRAPH_AXIS_UNITS_STATIC => _x('Static', 'history source selection method')
 		]))
-			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO)
-			->setAction('jQuery("#righty_static_units")'.
-							'.prop("disabled", (jQuery(this).val() != "'.SVG_GRAPH_AXIS_UNITS_STATIC.'"))'
-			);
+			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO);
 
 		if ($field_righty->getValue() != SVG_GRAPH_AXIS_SHOW) {
 			$field_righty_units->setFlags(CWidgetField::FLAG_DISABLED);
@@ -307,12 +305,14 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		// Checkbox: Selected items only.
 		$field_show_problems = (new CWidgetFieldCheckBox('show_problems', _('Show problems')))
 			->setAction(
-				'var on = jQuery(this).is(":checked");'.
-				'jQuery("#graph_item_problems, #problemhosts, #problem_name, #problemhosts_select")'.
+				'var on = jQuery(this).is(":checked"),'.
+					'widget = jQuery(this).closest(".ui-widget");'.
+				'jQuery("#graph_item_problems, #problem_name, #problemhosts_select")'.
 					'.prop("disabled", !on);'.
-				'jQuery("[name=\"severities[]\"]").prop("disabled", !on);'.
-				'jQuery("[name=\"evaltype\"]").prop("disabled", !on);'.
-				'jQuery("input, button", jQuery("#tags_table_tags")).prop("disabled", !on);'
+				'jQuery("#problemhosts_").multiSelect(on ? "enable" : "disable");'.
+				'jQuery("[name^=\"severities[\"]", widget).prop("disabled", !on);'.
+				'jQuery("[name=\"evaltype\"]", widget).prop("disabled", !on);'.
+				'jQuery("input, button", jQuery("#tags_table_tags", widget)).prop("disabled", !on);'
 			);
 
 		if (array_key_exists('show_problems', $this->data)) {
@@ -335,7 +335,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_problems->getName()] = $field_problems;
 
 		// Problem hosts.
-		$field_problemhosts = (new CWidgetFieldTextArea('problemhosts', _('Problem hosts')))
+		$field_problemhosts = (new CWidgetFieldHostPatternSelect('problemhosts', _('Problem hosts')))
 			->setPlaceholder(_('host pattern'));
 
 		if ($field_show_problems->getValue() != SVG_GRAPH_PROBLEMS_SHOW) {
@@ -348,8 +348,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_problemhosts->getName()] = $field_problemhosts;
 
 		// Severity checkboxes list.
-		$field_severities = (new CWidgetFieldSeverities('severities', _('Severity')))
-			->setOrientation(CWidgetFieldSeverities::ORIENTATION_HORIZONTAL);
+		$field_severities = new CWidgetFieldSeverities('severities', _('Severity'));
 
 		if ($field_show_problems->getValue() != SVG_GRAPH_PROBLEMS_SHOW) {
 			$field_severities->setFlags(CWidgetField::FLAG_DISABLED);
@@ -373,7 +372,7 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 
 		$this->fields[$field_problem_name->getName()] = $field_problem_name;
 
-		// Problem tag evalype (And/Or).
+		// Problem tag evaltype (And/Or).
 		$field_evaltype = (new CWidgetFieldRadioButtonList('evaltype', _('Tags'), [
 			TAG_EVAL_TYPE_AND_OR => _('And/Or'),
 			TAG_EVAL_TYPE_OR => _('Or')
@@ -468,50 +467,36 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 			));
 		}
 
+		$number_parser = new CNumberParser(['with_suffix' => true]);
+
 		// Validate Min/Max values in Axes tab.
 		if ($this->fields['lefty']->getValue() == SVG_GRAPH_AXIS_SHOW) {
-			$lefty_min = $this->fields['lefty_min']->getValue();
-			$lefty_max = $this->fields['lefty_max']->getValue();
-			$lefty_min = ($lefty_min !== '') ? convertFunctionValue($lefty_min, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT) : '';
-			$lefty_max = ($lefty_max !== '') ? convertFunctionValue($lefty_max, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT) : '';
-			$compare = true;
+			$lefty_min = $number_parser->parse($this->fields['lefty_min']->getValue()) == CParser::PARSE_SUCCESS
+				? $number_parser->calcValue()
+				: '';
 
-			if (strlen(substr(strrchr($lefty_min, '.'), 1)) > 4) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Min'), _('too many decimal places'));
-				$compare = false;
-			}
-			if (strlen(substr(strrchr($lefty_max, '.'), 1))  > 4) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Max'), _('too many decimal places'));
-				$compare = false;
-			}
+			$lefty_max = $number_parser->parse($this->fields['lefty_max']->getValue()) == CParser::PARSE_SUCCESS
+				? $number_parser->calcValue()
+				: '';
 
-			if ($compare && $lefty_min !== '' && $lefty_max !== ''
-					&& bccomp($lefty_min, $lefty_max, 4) >= 0) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Max'),
+			if ($lefty_min !== '' && $lefty_max !== '' && $lefty_min >= $lefty_max) {
+				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Left Y').'/'._('Max'),
 					_('Y axis MAX value must be greater than Y axis MIN value')
 				);
 			}
 		}
 
 		if ($this->fields['righty']->getValue() == SVG_GRAPH_AXIS_SHOW) {
-			$righty_min = $this->fields['righty_min']->getValue();
-			$righty_max = $this->fields['righty_max']->getValue();
-			$righty_min = ($righty_min != '') ? convertFunctionValue($righty_min, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT) : '';
-			$righty_max = ($righty_max != '') ? convertFunctionValue($righty_max, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT) : '';
-			$compare = true;
+			$righty_min = $number_parser->parse($this->fields['righty_min']->getValue()) == CParser::PARSE_SUCCESS
+				? $number_parser->calcValue()
+				: '';
 
-			if (strlen(substr(strrchr($righty_min, '.'), 1)) > 4) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Min'), _('too many decimal places'));
-				$compare = false;
-			}
-			if (strlen(substr(strrchr($righty_max, '.'), 1))  > 4) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Max'), _('too many decimal places'));
-				$compare = false;
-			}
+			$righty_max = $number_parser->parse($this->fields['righty_max']->getValue()) == CParser::PARSE_SUCCESS
+				? $number_parser->calcValue()
+				: '';
 
-			if ($compare && $righty_min !== '' && $righty_max !== ''
-					&& bccomp($righty_min, $righty_max, 4) >= 0) {
-				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Max'),
+			if ($righty_min !== '' && $righty_max !== '' && $righty_min >= $righty_max) {
+				$errors[] = _s('Invalid parameter "%1$s": %2$s.', _('Right Y').'/'._('Max'),
 					_('Y axis MAX value must be greater than Y axis MIN value')
 				);
 			}
