@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ $form_list = CWidgetHelper::createFormList($data['dialogue']['name'], $data['dia
 $scripts = [];
 
 // Time type.
-$form_list->addRow(CWidgetHelper::getLabel($fields['time_type']), CWidgetHelper::getComboBox($fields['time_type']));
+$form_list->addRow(CWidgetHelper::getLabel($fields['time_type']), CWidgetHelper::getSelect($fields['time_type']));
 
 // Item.
 if (array_key_exists('itemid', $fields)) {
@@ -44,6 +44,8 @@ if (array_key_exists('itemid', $fields)) {
 	$scripts[] = $field_itemid->getPostJS();
 }
 
+$scripts[] = '$("#time_type").on("change", updateWidgetConfigDialogue);';
+
 $form->addItem($form_list);
 
 return [
