@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -261,10 +261,11 @@ zbx_subarray_push($this->data['authTypeVisibility'], ITEM_AUTHTYPE_PUBLICKEY, 'r
 		$('#type')
 			.change(function() {
 				// update the interface select with each item type change
-				var itemInterfaceTypes = <?= json_encode(itemTypeInterface()) ?>;
+				var item_interface_types = <?= json_encode(itemTypeInterface()) ?>,
+					interface_ids_by_types = <?= json_encode($interface_ids_by_types) ?>;
 
 				updateItemTestBtn();
-				organizeInterfaces(itemInterfaceTypes[parseInt($(this).val())]);
+				organizeInterfaces(interface_ids_by_types, item_interface_types, parseInt($(this).val()));
 
 				setAuthTypeLabel();
 			})
@@ -272,7 +273,7 @@ zbx_subarray_push($this->data['authTypeVisibility'], ITEM_AUTHTYPE_PUBLICKEY, 'r
 
 		$('#test_item').on('click', function() {
 			var step_nums = [];
-			$('select[name^="preprocessing"][name$="[type]"]', $('#preprocessing')).each(function() {
+			$('z-select[name^="preprocessing"][name$="[type]"]', $('#preprocessing')).each(function() {
 				var str = $(this).attr('name');
 				step_nums.push(str.substr(14, str.length - 21));
 			});
